<?php
/**------------------------------------------------
*
* Rooty, 2021 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier NodeSettingsManager.php
*
* Ce fichier contient la classe NodeSettingsManager
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2021/04/19
* @version 0.1
* @package system_data
* @subpackage NodeSettings
* @copyright Copyright &copy; 2021, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################

/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
*<p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}


/**
* Appel à la classe Node...
*/
require ($CONF_LIB_PATH."lib/system/system_data/nodesettings/nodesettings.php");

/**
* Classe NodeSettingsManager
* 
* <P>Classe de gestion des instances de Nodes <br>
*   (permet de fabriquer, detruire, mettre à jour des objet Nodes)<br>
* Cette classe se sert des ressources à sa disposition (dans ./ressource)<br>
* Les Classes de ressource doivent avoir toutes les methodes correspondantes <br>
* aux methodes de la classe intitulés sourceXXX</P>
* 
* <p>Est configuré dans data_acces.php : <br>
* - La Source d'information (Db)<br>
* l'objet ressource se sert lui-même des classes d'accés aux données(lib/data_source/...)<br>
* </p>
* @package system_data
* @subpackage NodeSettings
*/
class NodeSettingsManager extends Manager
{

	//
	// Constructor
	//
/**
* Constructeur de la classe NodeSettingsManager PHP5
*
* @access public
*/
	function __construct()
	{
	}


###########################################################################
#### Méthodes abstraites
###########################################################################

/**
* doLoadFromId : charge les paramètres du Noeud
*
* <P>Chargement depuis la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant de du noeud
* @access public
* @abstract
* @return tableau tableau des éléments de paramètres d'un Noeud
*/
	function doLoadFromId($id)
	{
		return array();
	}

/**
* doUpdate : Update des paramètres du Noeud
*
* <P>Insertion dans la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant du Noeud père
* @param chaine libelle du Noeud
* @param chaine icone du Noeud
* @access public
* @abstract
* @return entier
*/
	function doUpdate($id, $email, $git, $mastodon, $mobilizon, $matrix, $peertube, $nextcloud, $twitter, $facebook)
	{
		return 0;	/* entier */
	}
	
/**
* doInsert : Insert des paramètres du Noeud
*
* <P>Insertion dans la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant du Noeud père
* @param chaine libelle du Noeud
* @param chaine icone du Noeud
* @access public
* @abstract
* @return entier
*/
	function doInsert($id, $email, $git, $mastodon, $mobilizon, $matrix, $peertube, $nextcloud, $twitter, $facebook)
	{
		return true;
	}

/**
* doDelete : Detruit les paramètres du Noeud
*
* <P>Suppression de l'objet à partir de son identifiant et dans la source de données</P>
* <P>Cette méthode a pour but d'être surchargée et de gérer les accés aux données</P>
* @param entier identifiant de du noeud
* @access public
* @abstract
* @return booleen
*/
	function doDelete($id)
	{
		return true;
	}

###########################################################################
#### Methodes privee
###########################################################################

/**
* sourceLoadFromId: charge à partir d'un identifiant
*
* <p>Permet le récupération des infos d'un objet Node à partir de son identifiant</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* <p>Retourne un tableau contenant les infos de l'objet<br>
* <br>ou faux si n'existe pas</p>
* @param identifiant du Noeud
* @access private
* @return tableau
*/
	function sourceLoadFromId($id)
	{
		$tab=$this->doLoadFromId($id);
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!is_array($tab))
		{
			/* Erreur */
			$systemError=1;
			$classe="NodeSettings";
			$message="Erreur dans NodeSettingsManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}else{
			if (!Is_numeric($tab["id"]))
			{
				/* Erreur */
				$systemError=1;
				$classe="NodeSettings";
				$message="Erreur dans NodeSettingsManager";
				addError($systemError,$classe,$message, __line__, __file__);
				return array();
			}else{
				return $tab;
			}
		}
	}

/**
* sourceInsert: Insert le Noeud
*
* <p>Insertion de l'objet Noeud dans la source de données<br>
* indifférement du type de cette source</p>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* <p>Retourne L'identifiant de l'objet inséré</p>
* @param entier identifiant du Noeud père
* @param chaine libelle du Noeud
* @param chaine icone du Noeud
* @access private
* @return entier
*/
	function sourceInsert($id, $email, $git, $mastodon, $mobilizon, $matrix, $peertube, $nextcloud, $twitter, $facebook)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!is_numeric($id))
		{
			/* Erreur */
			$systemError=1;
			$classe="NodeSettings";
			$message="Erreur dans NodeSettingsManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}
		return $this->doInsert($id, $email, $git, $mastodon, $mobilizon, $matrix, $peertube, $nextcloud, $twitter, $facebook);
	}

/**
* sourceUpdate: Met à jour le Noeud
*
* <P>Mise à jour de l'objet indifferemment de la source de données</P>
* <P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* @param entier identifiant du Noeud père
* @param chaine libelle du Noeud
* @param chaine icone du Noeud
* @access private
* @return booleen
*/
	function sourceUpdate($id, $email, $git, $mastodon, $mobilizon, $matrix, $peertube, $nextcloud, $twitter, $facebook)
	{
		# Gestion d'un tableau intermediaire avec la reprise des elements
		if (!Is_numeric($id))
		{
			/* Erreur */
			$systemError=1;
			$classe="NodeSettings";
			$message="Erreur dans NodeSettingsManager";
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}

		return $this->doUpdate($id, $email, $git, $mastodon, $mobilizon, $matrix, $peertube, $nextcloud, $twitter, $facebook);
	}

/**
* sourceDelete: Detruit le Noeud
*
*<p>Suppression de l'objet à partir de son identifiant</p>
*<P> Cette méthode gére le formatage des données avant leur passage à la source de données (methode doXXX equivalente)</P>
* @param entier identifiant de du noeud
* @access private
* @return booleen
*/
	function sourceDelete($id)
	{
		return $this->doDelete($id);
	}

###########################################################################
#### Methodes public
###########################################################################

/**
* createNewInstance : créer un objet vierge
*
* @access public
* @return objet
*/
	function createNewInstance()
	{
		return new NodeSettings();
	}
/**
* createInstance : récupere l'objet avec l'identifiant $id
*
* @param entier identifiant de l'association Node
* @access public 
* @return object retourne un objet de type Node
*/
	function createInstance($id)
	{
		$return = new NodeSettings();
		if (is_numeric($id))
		{
			/* Récupération des infos */
			$tab=$this->sourceLoadFromId($id);
			if (is_array($tab) && isset($tab["id"]) && is_numeric($tab["id"]))
			{
				/* création et alimentation de l'objet */
				$return->doLoad($tab["id"], $tab["email"], $tab["git"], $tab["mastodon"], $tab["mobilizon"], $tab["matrix"], $tab["peertube"], $tab["nextcloud"], $tab["twitter"], $tab["facebook"]);
			}else{
				$systemError=3;
				$classe="NodeSettingsManager";
				$message="Erreur id inexistant ".$id;
				addError($systemError, $classe, $message, __line__, __file__);				
			}
		}else{
			$systemError=3;
			$classe="NodeSettingsManager";
			$message="Erreur id invalide ".$id;
			addError($systemError, $classe, $message, __line__, __file__);
		}
		return $return;
	}

/**
* deleteInstance : detruit l'objet physique
*
* @param object objet Node à effacer
* @access public
* @return object objetNode mis à jour
*/
	function deleteInstance($obj)
	{
		$return = false;
		if ( strtolower(get_class($obj))=="nodesettings" )
		{
			if($obj->isLoaded()==true)
			{
				/* Récupération des infos */
				$this->CallSystemPlugin("__deleteNodeSettings", $obj);
				$return=$this->sourceDelete($obj->getId());
				$obj->setId(0);
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="NodeSettingsManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}

/**
* updateInstance : met à jour l'objet
*
* @param object objet Node à modifier
* @access public
* @return object objetNode mis à jour
*/
	function updateInstance($obj)
	{
		$return = false;
		if ((strtolower(get_class($obj))=="nodesettings") && ($obj->isLoaded()==true))
		{
			/* Récupération des infos */
			$id=$this->sourceUpdate($obj->getId(), $obj->getEmail(), $obj->getGit(), $obj->getMastodon(), $obj->getMobilizon(), $obj->getMatrix(), $obj->getPeertube(), $obj->getNextcloud(), $obj->getTwitter(), $obj->getFacebook());
			$this->CallSystemPlugin("__updateNodeSettings", $obj);
			return $obj;
		}
		/* Erreur */
		$systemError=3;
		$classe="NodeSettingsManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* insertInstance : créer enregistre l'objet
*
* <p>affecte l'id de l'objet si nécessaire</p>
* @param object objet Node à inserer
* @access public
* @return object objetNode mis à jour
*/
	function insertInstance($obj)
	{
		if ((strtolower(get_class($obj))==strtolower("NodeSettings")))
		{
			if ($obj->isLoaded()==true)
			{
				/* Récupération des infos */
				$id=$this->sourceInsert($obj->getId(), $obj->getEmail(), $obj->getGit(), $obj->getMastodon(), $obj->getMobilizon(), $obj->getMatrix(), $obj->getPeertube(), $obj->getNextcloud(), $obj->getTwitter(), $obj->getFacebook());
// 				$obj->setId($id);
				$this->CallSystemPlugin("__insertNodeSettings", $obj);
				return $obj;
			} else {
				/* Erreur */
				$systemError=3;
				$classe="NodeSettingsManager";
				$message="Erreur ! Aucun ID d'objet ! ";
				addError($systemError, $classe, $message, __line__, __file__);
				
				return $obj;
			}
		}
		/* Erreur */
		$systemError=3;
		$classe="NodeSettingsManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);

		return $obj;
	}
/**
* saveInstance : créer enregistre l'objet
*
* @param object objet Node à sauvegarder
* @access public
* @return object objetNode mis à jour
*/
	function saveInstance($obj)
	{
		if ((strtolower(get_class($obj))==strtolower("NodeSettings")))
		{
			if ($obj->isLoaded()==false)
			{
				$return=$this->insertInstance($obj);
			}else{
				$return=$this->updateInstance($obj);
			}
			return $return;
		}

		/* Erreur */
		$systemError=3;
		$classe="NodeSettingsManager";
		$message="Erreur objet invalide ";
		addError($systemError, $classe, $message, __line__, __file__);
		$return=$obj;

		return $return;
	}
}
?>
